RGCNRepresentation
==================

.. currentmodule:: pykeen.nn.message_passing

.. autoclass:: RGCNRepresentation
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~RGCNRepresentation.post_parameter_update
      ~RGCNRepresentation.reset_parameters

   .. rubric:: Methods Documentation

   .. automethod:: post_parameter_update
   .. automethod:: reset_parameters
